@@ -30,6 +30,8 @@
 #include <QStandardPaths>
 #include <QStringList>
 #include <click.h>
+#include <sys/types.h>
+#include <utime.h>
 
 static QString findPackageDir(const QString &appId)
 {
@@ -92,6 +94,8 @@ public:
     void addServiceType(const QString &shortAppId);
     void checkIconPath(const QString &appId);
     bool writeTo(const QString &fileName) const;
+    void addCreatorMark();
+    bool createdByUs() const;
     bool isValid() const { return m_isValid; }
 
 private:
@@ -210,6 +214,10 @@ bool LibAccountsFile::writeTo(const QString &fileName) const
     file.close();
 
     if (ok) {
+        struct utimbuf sourceTime;
+        sourceTime.actime = sourceTime.modtime =
+            m_hookFileInfo.lastModified().toTime_t();
+        utime(fileName.toUtf8().constData(), &sourceTime);
         return true;
     } else {
         QFile::remove(fileName);
@@ -217,7 +225,38 @@ bool LibAccountsFile::writeTo(const QString &fileName) const
     }
 }
 
-static void removeStaleFiles(const QStringList &fileTypes,
+void LibAccountsFile::addCreatorMark()
+{
+    QString comment = QString("this file is auto-generated by %1; do not modify").
+        arg(QCoreApplication::applicationName());
+    appendChild(createComment(comment));
+}
+
+bool LibAccountsFile::createdByUs() const
+{
+    QString creatorMark = QCoreApplication::applicationName() + ";";
+    for (QDomNode n = firstChild(); !n.isNull(); n = n.nextSibling()) {
+        if (n.isComment() && n.nodeValue().contains(creatorMark)) {
+            return true;
+        }
+    }
+    return false;
+}
+
+static void removeStaleAccounts(Accounts::Manager *manager,
+                                const QString &providerName)
+{
+    Q_FOREACH(Accounts::AccountId id, manager->accountList()) {
+        Accounts::Account *account = manager->account(id);
+        if (account->providerName() == providerName) {
+            account->remove();
+            account->syncAndBlock();
+        }
+    }
+}
+
+static void removeStaleFiles(Accounts::Manager *manager,
+                             const QStringList &fileTypes,
                              const QString &localShare,
                              const QDir &hooksDirIn)
 {
@@ -235,18 +274,23 @@ static void removeStaleFiles(const QStringList &fileTypes,
         Q_FOREACH(const QFileInfo &fileInfo, dir.entryInfoList()) {
             LibAccountsFile file(fileInfo.filePath());
 
-            QString profile = file.profile();
+            /* If this file was not created by our hook let's ignore it. */
+            if (!file.createdByUs()) continue;
 
-            /* If there is no <profile> element, then this file was not created
-             * by our hook; let's ignore it. */
-            if (profile.isEmpty()) continue;
+            QString profile = file.profile();
 
             /* Check that the hook file is still there; if it isn't, then it
              * means that the click package was removed, and we must remove our
              * copy as well. */
-            QString hookFileName = profile + "." + fileType;
-            if (!hooksDirIn.exists(hookFileName)) {
-                QFile::remove(fileInfo.filePath());
+            QString hookFileName = stripVersion(profile) + "_*." + fileType;
+            QStringList nameFilters = QStringList() << hookFileName;
+            if (!hooksDirIn.entryList(nameFilters).isEmpty()) continue;
+
+            QFile::remove(fileInfo.filePath());
+            /* If this is a provider, we must also remove any accounts
+             * associated with it */
+            if (fileType == QStringLiteral("provider")) {
+                removeStaleAccounts(manager, fileInfo.completeBaseName());
             }
         }
     }
@@ -256,6 +300,12 @@ int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
 
+    Accounts::Manager::Options managerOptions;
+    if (qgetenv("DBUS_SESSION_BUS_ADDRESS").isEmpty()) {
+        managerOptions |= Accounts::Manager::DisableNotifications;
+    }
+    Accounts::Manager *manager = new Accounts::Manager(managerOptions);
+
     /* Go through the hook files in ~/.local/share/online-accounts-hooks/ and
      * check if they have already been processed into a file under
      * ~/.local/share/accounts/{providers,services,service-types,applications}/;
@@ -274,7 +324,7 @@ int main(int argc, char **argv)
         QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
     QDir hooksDirIn(localShare + "/" HOOK_FILES_SUBDIR);
 
-    removeStaleFiles(fileTypes, localShare, hooksDirIn);
+    removeStaleFiles(manager, fileTypes, localShare, hooksDirIn);
 
     Q_FOREACH(const QFileInfo &fileInfo, hooksDirIn.entryInfoList()) {
         const QString fileType = fileInfo.suffix();
@@ -298,13 +348,14 @@ int main(int argc, char **argv)
         QFileInfo destinationInfo(destination);
         /* If the destination is there and up to date, we have nothing to do */
         if (destinationInfo.exists() &&
-            destinationInfo.lastModified() >= fileInfo.lastModified()) {
+            destinationInfo.lastModified() == fileInfo.lastModified()) {
             continue;
         }
 
         LibAccountsFile xml = LibAccountsFile(fileInfo);
         if (!xml.isValid()) continue;
 
+        xml.addCreatorMark();
         xml.checkId(shortAppId);
         xml.addProfile(appId);
         xml.addPackageDir(appId);
@@ -320,8 +371,7 @@ int main(int argc, char **argv)
     /* To ensure that all the installed services are parsed into
      * libaccounts' DB, we enumerate them now.
      */
-    Accounts::Manager *manager =
-        new Accounts::Manager(Accounts::Manager::DisableNotifications);
+    manager->serviceList();
     delete manager;
 
     return EXIT_SUCCESS;
