@@ -30,10 +30,15 @@
 #include <QCoreApplication>
 #include <QDBusConnection>
 #include <QDBusMetaType>
+#include <QLibrary>
 #include <QProcessEnvironment>
 
 using namespace OnlineAccountsUi;
 
+#define ONLINE_ACCOUNTS_MANAGER_SERVICE_NAME \
+    "com.ubuntu.OnlineAccounts.Manager"
+#define ONLINE_ACCOUNTS_MANAGER_PATH "/com/ubuntu/OnlineAccounts/Manager"
+
 int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
@@ -66,28 +71,46 @@ int main(int argc, char **argv)
 
     Service *service = new Service();
     QDBusConnection connection = QDBusConnection::sessionBus();
-    connection.registerService(OAU_SERVICE_NAME);
     connection.registerObject(OAU_OBJECT_PATH, service);
+    connection.registerService(OAU_SERVICE_NAME);
 
     SignOnUi::Service *signonuiService = new SignOnUi::Service();
-    connection.registerService(SIGNONUI_SERVICE_NAME);
     connection.registerObject(SIGNONUI_OBJECT_PATH, signonuiService,
                               QDBusConnection::ExportAllContents);
+    connection.registerService(SIGNONUI_SERVICE_NAME);
 
     SignOnUi::IndicatorService *indicatorService =
         new SignOnUi::IndicatorService();
-    connection.registerService(WEBCREDENTIALS_BUS_NAME);
     connection.registerObject(WEBCREDENTIALS_OBJECT_PATH,
                               indicatorService->serviceObject());
+    connection.registerService(WEBCREDENTIALS_BUS_NAME);
 
     LibaccountsService *libaccountsService = new LibaccountsService();
-    connection.registerService(LIBACCOUNTS_BUS_NAME);
     connection.registerObject(LIBACCOUNTS_OBJECT_PATH, libaccountsService,
                               QDBusConnection::ExportAllContents);
+    connection.registerService(LIBACCOUNTS_BUS_NAME);
+
+    /* V2 API; we load it dynamically in order to resolve a build-time
+     * circular dependency loop. */
+    QLibrary v2lib("OnlineAccountsDaemon");
+    typedef QObject *(*CreateManager)(QObject *);
+    CreateManager createManager =
+        (CreateManager) v2lib.resolve("oad_create_manager");
+    QObject *v2api = createManager ? createManager(0) : 0;
+    if (v2api) {
+        connection.registerObject(ONLINE_ACCOUNTS_MANAGER_PATH, v2api);
+        connection.registerService(ONLINE_ACCOUNTS_MANAGER_SERVICE_NAME);
+        connection.connect(QString(),
+                           QStringLiteral("/org/freedesktop/DBus/Local"),
+                           QStringLiteral("org.freedesktop.DBus.Local"),
+                           QStringLiteral("Disconnected"),
+                           v2api, SLOT(onDisconnected()));
+    }
 
     InactivityTimer *inactivityTimer = 0;
     if (daemonTimeout > 0) {
         inactivityTimer = new InactivityTimer(daemonTimeout * 1000);
+        inactivityTimer->watchObject(v2api);
         inactivityTimer->watchObject(requestManager);
         inactivityTimer->watchObject(indicatorService);
         QObject::connect(inactivityTimer, SIGNAL(timeout()),
@@ -96,6 +119,12 @@ int main(int argc, char **argv)
 
     int ret = app.exec();
 
+    if (v2api) {
+        connection.unregisterService(ONLINE_ACCOUNTS_MANAGER_SERVICE_NAME);
+        connection.unregisterObject(ONLINE_ACCOUNTS_MANAGER_PATH);
+        delete v2api;
+    }
+
     connection.unregisterService(LIBACCOUNTS_BUS_NAME);
     connection.unregisterObject(LIBACCOUNTS_OBJECT_PATH);
     delete libaccountsService;
