@@ -21,7 +21,10 @@
 #include "debug.h"
 #include "globals.h"
 #include "request.h"
+#include "utils.h"
 
+#include <Accounts/Manager>
+#include <Accounts/Service>
 #include <SignOn/uisessiondata_priv.h>
 
 using namespace OnlineAccountsUi;
@@ -57,9 +60,6 @@ public:
         return m_parameters[OAU_KEY_WINDOW_ID].toUInt();
     }
 
-private:
-    QString findClientApparmorProfile();
-
 private:
     mutable Request *q_ptr;
     QDBusConnection m_connection;
@@ -84,41 +84,13 @@ RequestPrivate::RequestPrivate(const QDBusConnection &connection,
     m_inProgress(false),
     m_delay(0)
 {
-    m_clientApparmorProfile = findClientApparmorProfile();
+    m_clientApparmorProfile = apparmorProfileOfPeer(message);
 }
 
 RequestPrivate::~RequestPrivate()
 {
 }
 
-QString RequestPrivate::findClientApparmorProfile()
-{
-    QString uniqueConnectionId = m_message.service();
-    /* This is mainly for unit tests: real messages on the session bus always
-     * have a service name. */
-    if (uniqueConnectionId.isEmpty()) return QString();
-
-    QString appId;
-
-    QDBusMessage msg =
-        QDBusMessage::createMethodCall("org.freedesktop.DBus",
-                                       "/org/freedesktop/DBus",
-                                       "org.freedesktop.DBus",
-                                       "GetConnectionAppArmorSecurityContext");
-    QVariantList args;
-    args << uniqueConnectionId;
-    msg.setArguments(args);
-    QDBusMessage reply = QDBusConnection::sessionBus().call(msg, QDBus::Block);
-    if (reply.type() == QDBusMessage::ReplyMessage) {
-        appId = reply.arguments().value(0, QString()).toString();
-        DEBUG() << "App ID:" << appId;
-    } else {
-        qWarning() << "Error getting app ID:" << reply.errorName() <<
-            reply.errorMessage();
-    }
-    return appId;
-}
-
 Request::Request(const QDBusConnection &connection,
                  const QDBusMessage &message,
                  const QVariantMap &parameters,
@@ -157,6 +129,13 @@ pid_t Request::clientPid() const
     if (interface() == OAU_INTERFACE) {
         return d->m_parameters.value(OAU_KEY_PID, 0).toUInt();
     } else if (interface() == SIGNONUI_INTERFACE) {
+        if (d->m_clientApparmorProfile == "unconfined") {
+            QVariantMap clientData =
+                d->m_parameters.value(SSOUI_KEY_CLIENT_DATA).toMap();
+            if (clientData.contains("requestorPid")) {
+                return clientData.value("requestorPid").toUInt();
+            }
+        }
         return d->m_parameters.value(SSOUI_KEY_PID, 0).toUInt();
     }
 
@@ -192,6 +171,27 @@ QString Request::interface() const {
     return d->m_message.interface();
 }
 
+QString Request::providerId() const
+{
+    Q_D(const Request);
+    if (interface() == OAU_INTERFACE) {
+        QString providerId =
+            d->m_parameters.value(OAU_KEY_PROVIDER).toString();
+        if (providerId.isEmpty() &&
+            d->m_parameters.contains(OAU_KEY_SERVICE_ID)) {
+            Accounts::Manager manager;
+            QString serviceId = d->m_parameters[OAU_KEY_SERVICE_ID].toString();
+            Accounts::Service service = manager.service(serviceId);
+            if (service.isValid()) {
+                providerId = service.provider();
+            }
+        }
+        return providerId;
+    } else {
+        return QString();
+    }
+}
+
 void Request::setDelay(int delay)
 {
     Q_D(Request);
