@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2014 Canonical Ltd.
+ * Copyright (C) 2013-2015 Canonical Ltd.
  *
  * Contact: Alberto Mardegan <alberto.mardegan@canonical.com>
  *
@@ -23,20 +23,16 @@
 #include "i18n.h"
 #include "ui-server.h"
 
-#include <QtGui/QOpenGLContext>
 #include <QGuiApplication>
 #include <QLibrary>
 #include <QProcessEnvironment>
-#if QT_VERSION < QT_VERSION_CHECK(5, 3, 0)
-#include <QtQuick/private/qsgcontext_p.h>
-#else
-#include <QtGui/private/qopenglcontext_p.h>
-#endif
+#include <sys/apparmor.h>
 
 using namespace OnlineAccountsUi;
 
 int main(int argc, char **argv)
 {
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QGuiApplication app(argc, argv);
 
     /* The testability driver is only loaded by QApplication but not by
@@ -72,23 +68,27 @@ int main(int argc, char **argv)
 
     initTr(I18N_DOMAIN, NULL);
 
-    // Enable compositing in oxide
-    QOpenGLContext *glcontext = new QOpenGLContext();
-    glcontext->create();
-#if QT_VERSION < QT_VERSION_CHECK(5, 3, 0)
-    QSGContext::setSharedOpenGLContext(glcontext);
-#else
-    QOpenGLContextPrivate::setGlobalShareContext(glcontext);
-#endif
-
+    QString socket;
+    QString profile;
     QStringList arguments = app.arguments();
-    int i = arguments.indexOf("--socket");
-    if (i < 0 || i + 1 >= arguments.count()) {
+    for (int i = 0; i < arguments.count(); i++) {
+        const QString &arg = arguments[i];
+        if (arg == "--socket") {
+            socket = arguments.value(++i);
+        } else if (arg == "--profile") {
+            profile = arguments.value(++i);
+        }
+    }
+    if (Q_UNLIKELY(socket.isEmpty())) {
         qWarning() << "Missing --socket argument";
         return EXIT_FAILURE;
     }
 
-    UiServer server(arguments[i + 1]);
+    if (!profile.isEmpty()) {
+        aa_change_profile(profile.toUtf8().constData());
+    }
+
+    UiServer server(socket);
     QObject::connect(&server, SIGNAL(finished()),
                      &app, SLOT(quit()));
     if (Q_UNLIKELY(!server.init())) {
