@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013 Canonical Ltd.
+ * Copyright (C) 2015 Canonical Ltd.
  *
  * Contact: Alberto Mardegan <alberto.mardegan@canonical.com>
  *
@@ -22,15 +22,13 @@
 #include <QObject>
 #include <SystemSettings/PluginInterface>
 
-class Plugin: public QObject, public SystemSettings::PluginInterface
+class Plugin: public QObject, public SystemSettings::PluginInterface2
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "com.ubuntu.SystemSettings.PluginInterface")
-    Q_INTERFACES(SystemSettings::PluginInterface)
+    Q_PLUGIN_METADATA(IID "com.ubuntu.SystemSettings.PluginInterface/2.0")
+    Q_INTERFACES(SystemSettings::PluginInterface2)
 
 public:
-    Plugin();
-
     SystemSettings::ItemBase *createItem(const QVariantMap &staticData,
                                          QObject *parent = 0);
 };
