@@ -334,6 +334,7 @@ void OnlineAccountsHooksTest::testRemoval()
     QString stillInstalled("applications/com.ubuntu.test_StillInstalled.application");
     writeInstalledFile(stillInstalled,
         "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
+        "<!--this file is auto-generated by online-accounts-hooks; do not modify-->\n"
         "<application>\n"
         "  <description>My application</description>\n"
         "  <service-types>\n"
@@ -346,6 +347,7 @@ void OnlineAccountsHooksTest::testRemoval()
     QString myApp("applications/com.ubuntu.test_MyApp.application");
     writeInstalledFile(myApp,
         "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
+        "<!--this file is auto-generated by online-accounts-hooks; do not modify-->\n"
         "<application>\n"
         "  <description>My application</description>\n"
         "  <service-types>\n"
@@ -366,6 +368,19 @@ void OnlineAccountsHooksTest::testRemoval()
         "</application>");
     QVERIFY(m_installDir.exists(noProfile));
 
+    QString notOurs("applications/com.ubuntu.test_NotOurs.application");
+    writeInstalledFile(notOurs,
+        "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
+        "<!--this file is auto-generated by online-accounts-hooks2; do not modify-->\n"
+        "<application>\n"
+        "  <description>My application</description>\n"
+        "  <service-types>\n"
+        "    <service-type>some type</service-type>\n"
+        "  </service-types>\n"
+        "  <profile>com-ubuntu.test_NotOurs_0.1.0</profile>\n"
+        "</application>");
+    QVERIFY(m_installDir.exists(notOurs));
+
     writeHookFile("com-ubuntu.test_StillInstalled_2.0.application",
         "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
         "<application>\n"
@@ -380,6 +395,7 @@ void OnlineAccountsHooksTest::testRemoval()
     QVERIFY(m_installDir.exists(stillInstalled));
     QVERIFY(!m_installDir.exists(myApp));
     QVERIFY(m_installDir.exists(noProfile));
+    QVERIFY(m_installDir.exists(noProfile));
 }
 
 void OnlineAccountsHooksTest::testAccountRemoval()
@@ -393,12 +409,15 @@ void OnlineAccountsHooksTest::testAccountRemoval()
     QString stillInstalled("providers/com.ubuntu.test_StillInstalled.provider");
     writeInstalledFile(stillInstalled,
         "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
+        "<!--this file is auto-generated by online-accounts-hooks; do not modify-->\n"
         "<provider>\n"
         "  <profile>com-ubuntu.test_StillInstalled_2.0</profile>\n"
         "</provider>");
     QVERIFY(m_installDir.exists(stillInstalled));
 
-    writeHookFile("com-ubuntu.test_StillInstalled_2.0.provider",
+    /* Write a newer version of the hook, to make sure that accounts created
+     * with older versions of the app are preserved */
+    writeHookFile("com-ubuntu.test_StillInstalled_3.0.provider",
         "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
         "<provider>\n"
         "</provider>");
@@ -413,6 +432,7 @@ void OnlineAccountsHooksTest::testAccountRemoval()
     QString myProvider("providers/com.ubuntu.test_MyProvider.provider");
     writeInstalledFile(myProvider,
         "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
+        "<!--this file is auto-generated by online-accounts-hooks; do not modify-->\n"
         "<provider>\n"
         "  <profile>com-ubuntu.test_MyProvider_3.0</profile>\n"
         "</provider>");
@@ -471,6 +491,7 @@ void OnlineAccountsHooksTest::testUpdate()
 
     /* Now remove the hook file and write a newer version of it */
     clearHooksDir();
+    QTest::qWait(1500); // make sure that the timestamp is newer
     writeHookFile("com-ubuntu.test_MyApp_1.1.application",
         "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n"
         "<application>\n"
