@@ -48,6 +48,11 @@ void RequestPrivate::setClientApparmorProfile(const QString &profile)
     m_clientApparmorProfile = profile;
 }
 
+void RequestPrivate::setProviderId(const QString &provider)
+{
+    m_providerId = provider;
+}
+
 Request::Request(const QDBusConnection &connection,
                  const QDBusMessage &message,
                  const QVariantMap &parameters,
@@ -96,6 +101,11 @@ QString Request::interface() const {
     return d->m_message.interface();
 }
 
+QString Request::providerId() const {
+    Q_D(const Request);
+    return d->m_providerId;
+}
+
 void Request::setDelay(int delay)
 {
     Q_D(Request);
